---
title: Helm Chart Values
menuTitle: Helm Chart Values
description: Reference for Helm Chart values.
aliases:
  - /docs/writers-toolkit/latest/templates/reference-template
weight: 100
keywords:
  - keyword 1
  - keyword 2
  - keyword 3
---

<!-- Autogenerated. Modify ../production/helm/loki/reference.md.gotmpl -->

# Helm Chart Values
<!-- vale Grafana.Quotes = NO -->
<!-- The reference title is required. Use a noun-based title. -->
<!-- vale Grafana.Quotes = YES -->

This is the generade reference for the Loki Helm Chart values.

<!-- Override default values table from helm-docs. See https://github.com/norwoodj/helm-docs/tree/master#advanced-table-rendering -->

{{< responsive-table >}}
<table>
	<thead>
		<th>Key</th>
		<th>Type</th>
		<th>Description</th>
		<th>Default</th>
	</thead>
	<tbody>
		<tr>
			<td>enterprise.adminApi</td>
			<td>object</td>
			<td>If enabled, the correct admin_client storage will be configured. If disabled while running enterprise, make sure auth is set to `type: trust`, or that `auth_enabled` is set to `false`.</td>
			<td><pre lang="json">
{
  "enabled": true
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.adminTokenSecret</td>
			<td>string</td>
			<td>Alternative name for admin token secret, needed by tokengen and provisioner jobs</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.canarySecret</td>
			<td>string</td>
			<td>Alternative name of the secret to store token for the canary</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.cluster_name</td>
			<td>string</td>
			<td>Optional name of the GEL cluster, otherwise will use .Release.Name The cluster name must match what is in your GEL license</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.config</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"{{- if .Values.enterprise.adminApi.enabled }}\n{{- if or .Values.minio.enabled (eq .Values.loki.storage.type \"s3\") (eq .Values.loki.storage.type \"gcs\") }}\nadmin_client:\n  storage:\n    s3:\n      bucket_name: {{ .Values.loki.storage.bucketNames.admin }}\n{{- end }}\n{{- end }}\nauth:\n  type: {{ .Values.enterprise.adminApi.enabled | ternary \"enterprise\" \"trust\" }}\nauth_enabled: {{ .Values.loki.auth_enabled }}\ncluster_name: {{ include \"loki.clusterName\" . }}\nlicense:\n  path: /etc/loki/license/license.jwt\n"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.externalLicenseName</td>
			<td>string</td>
			<td>Name of external licesne secret to use</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/enterprise-logs"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
"v1.4.0"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.license</td>
			<td>object</td>
			<td>Grafana Enterprise Logs license In order to use Grafana Enterprise Logs features, you will need to provide the contents of your Grafana Enterprise Logs license, either by providing the contents of the license.jwt, or the name Kubernetes Secret that contains your license.jwt. To set the license contents, use the flag `--set-file 'license.contents=./license.jwt'`</td>
			<td><pre lang="json">
{
  "contents": "NOTAVALIDLICENSE"
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.nginxConfig.file</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"worker_processes  5;  ## Default: 1\nerror_log  /dev/stderr;\npid        /tmp/nginx.pid;\nworker_rlimit_nofile 8192;\n\nevents {\n  worker_connections  4096;  ## Default: 1024\n}\n\nhttp {\n  client_body_temp_path /tmp/client_temp;\n  proxy_temp_path       /tmp/proxy_temp_path;\n  fastcgi_temp_path     /tmp/fastcgi_temp;\n  uwsgi_temp_path       /tmp/uwsgi_temp;\n  scgi_temp_path        /tmp/scgi_temp;\n\n  proxy_http_version    1.1;\n\n  default_type application/octet-stream;\n  log_format   {{ .Values.gateway.nginxConfig.logFormat }}\n\n  {{- if .Values.gateway.verboseLogging }}\n  access_log   /dev/stderr  main;\n  {{- else }}\n\n  map $status $loggable {\n    ~^[23]  0;\n    default 1;\n  }\n  access_log   /dev/stderr  main  if=$loggable;\n  {{- end }}\n\n  sendfile     on;\n  tcp_nopush   on;\n  resolver {{ .Values.global.dnsService }}.{{ .Values.global.dnsNamespace }}.svc.{{ .Values.global.clusterDomain }}.;\n\n  {{- with .Values.gateway.nginxConfig.httpSnippet }}\n  {{ . | nindent 2 }}\n  {{- end }}\n\n  server {\n    listen             8080;\n\n    {{- if .Values.gateway.basicAuth.enabled }}\n    auth_basic           \"Loki\";\n    auth_basic_user_file /etc/nginx/secrets/.htpasswd;\n    {{- end }}\n\n    location = / {\n      return 200 'OK';\n      auth_basic off;\n    }\n\n    location = /api/prom/push {\n      proxy_pass       http://{{ include \"loki.writeFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location = /api/prom/tail {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n      proxy_set_header Upgrade $http_upgrade;\n      proxy_set_header Connection \"upgrade\";\n    }\n\n    location ~ /api/prom/.* {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /prometheus/api/v1/alerts.* {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /prometheus/api/v1/rules.* {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location = /loki/api/v1/push {\n      proxy_pass       http://{{ include \"loki.writeFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location = /loki/api/v1/tail {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n      proxy_set_header Upgrade $http_upgrade;\n      proxy_set_header Connection \"upgrade\";\n    }\n\n    location ~ /loki/api/.* {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /admin/api/.* {\n      proxy_pass       http://{{ include \"loki.writeFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /compactor/.* {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /distributor/.* {\n      proxy_pass       http://{{ include \"loki.writeFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /ring {\n      proxy_pass       http://{{ include \"loki.writeFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /ingester/.* {\n      proxy_pass       http://{{ include \"loki.writeFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /ruler/.* {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    location ~ /scheduler/.* {\n      proxy_pass       http://{{ include \"loki.readFullname\" . }}.{{ .Release.Namespace }}.svc.{{ .Values.global.clusterDomain }}:3100$request_uri;\n    }\n\n    {{- with .Values.gateway.nginxConfig.serverSnippet }}\n    {{ . | nindent 4 }}\n    {{- end }}\n  }\n}\n"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner</td>
			<td>object</td>
			<td>Configuration for `provisioner` target</td>
			<td><pre lang="json">
{
  "annotations": {},
  "enabled": true,
  "env": [],
  "image": {
    "pullPolicy": "IfNotPresent",
    "registry": "docker.io",
    "repository": "grafana/enterprise-logs-provisioner",
    "tag": null
  },
  "labels": {},
  "priorityClassName": null,
  "provisionedSecretPrefix": "{{ include \"loki.name\" . }}-provisioned",
  "securityContext": {
    "fsGroup": 10001,
    "runAsGroup": 10001,
    "runAsNonRoot": true,
    "runAsUser": 10001
  },
  "tenants": []
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.annotations</td>
			<td>object</td>
			<td>Additional annotations for the `provisioner` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.enabled</td>
			<td>bool</td>
			<td>Whether the job should be part of the deployment</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.env</td>
			<td>list</td>
			<td>Additional Kubernetes environment</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image</td>
			<td>object</td>
			<td>Provisioner image to Utilize</td>
			<td><pre lang="json">
{
  "pullPolicy": "IfNotPresent",
  "registry": "docker.io",
  "repository": "grafana/enterprise-logs-provisioner",
  "tag": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/enterprise-logs-provisioner"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.labels</td>
			<td>object</td>
			<td>Additional labels for the `provisioner` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for provisioner Job</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.provisionedSecretPrefix</td>
			<td>string</td>
			<td>Name of the secret to store provisioned tokens in</td>
			<td><pre lang="json">
"{{ include \"loki.name\" . }}-provisioned"
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.securityContext</td>
			<td>object</td>
			<td>Run containers as user `enterprise-logs(uid=10001)`</td>
			<td><pre lang="json">
{
  "fsGroup": 10001,
  "runAsGroup": 10001,
  "runAsNonRoot": true,
  "runAsUser": 10001
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.provisioner.tenants</td>
			<td>list</td>
			<td>Tenants to be created. Each tenant will get a read and write policy and associated token.</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen</td>
			<td>object</td>
			<td>Configuration for `tokengen` target</td>
			<td><pre lang="json">
{
  "annotations": {},
  "enabled": true,
  "env": [],
  "extraArgs": [],
  "extraEnvFrom": [],
  "extraVolumeMounts": [],
  "extraVolumes": [],
  "labels": {},
  "securityContext": {
    "fsGroup": 10001,
    "runAsGroup": 10001,
    "runAsNonRoot": true,
    "runAsUser": 10001
  },
  "tolerations": []
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.annotations</td>
			<td>object</td>
			<td>Additional annotations for the `tokengen` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.enabled</td>
			<td>bool</td>
			<td>Whether the job should be part of the deployment</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.env</td>
			<td>list</td>
			<td>Additional Kubernetes environment</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraArgs</td>
			<td>list</td>
			<td>Additional CLI arguments for the `tokengen` target</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the tokengen pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraVolumeMounts</td>
			<td>list</td>
			<td>Additional volume mounts for Pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.extraVolumes</td>
			<td>list</td>
			<td>Additional volumes for Pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.labels</td>
			<td>object</td>
			<td>Additional labels for the `tokengen` Job</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.securityContext</td>
			<td>object</td>
			<td>Run containers as user `enterprise-logs(uid=10001)`</td>
			<td><pre lang="json">
{
  "fsGroup": 10001,
  "runAsGroup": 10001,
  "runAsNonRoot": true,
  "runAsUser": 10001
}
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.tokengen.tolerations</td>
			<td>list</td>
			<td>Tolerations for tokengen Job</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.useExternalLicense</td>
			<td>bool</td>
			<td>Set to true when providing an external license</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>enterprise.version</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"v1.5.2"
</pre>
</td>
		</tr>
		<tr>
			<td>fullnameOverride</td>
			<td>string</td>
			<td>Overrides the chart's computed fullname</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.affinity</td>
			<td>string</td>
			<td>Affinity for gateway pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling for the gateway</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the gateway</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the gateway</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilisation percentage for the gateway</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilisation percentage for the gateway</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.enabled</td>
			<td>bool</td>
			<td>Enables basic authentication for the gateway</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.existingSecret</td>
			<td>string</td>
			<td>Existing basic auth secret to use. Must contain '.htpasswd'</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.htpasswd</td>
			<td>string</td>
			<td>Uses the specified username and password to compute a htpasswd using Sprig's `htpasswd` function. The value is templated using `tpl`. Override this to use a custom htpasswd, e.g. in case the default causes high CPU load.</td>
			<td><pre lang="json">
"{{ htpasswd (required \"'gateway.basicAuth.username' is required\" .Values.gateway.basicAuth.username) (required \"'gateway.basicAuth.password' is required\" .Values.gateway.basicAuth.password) }}"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.password</td>
			<td>string</td>
			<td>The basic auth password for the gateway</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.basicAuth.username</td>
			<td>string</td>
			<td>The basic auth username for the gateway</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.containerSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for gateway containers</td>
			<td><pre lang="json">
{
  "allowPrivilegeEscalation": false,
  "capabilities": {
    "drop": [
      "ALL"
    ]
  },
  "readOnlyRootFilesystem": true
}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.deploymentStrategy</td>
			<td>object</td>
			<td>ref: https://kubernetes.io/docs/concepts/workloads/controllers/deployment/#strategy</td>
			<td><pre lang="json">
{
  "type": "RollingUpdate"
}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.enabled</td>
			<td>bool</td>
			<td>Specifies whether the gateway should be enabled</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the gateway</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.pullPolicy</td>
			<td>string</td>
			<td>The gateway image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the gateway image</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.repository</td>
			<td>string</td>
			<td>The gateway image repository</td>
			<td><pre lang="json">
"nginxinc/nginx-unprivileged"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.image.tag</td>
			<td>string</td>
			<td>The gateway image tag</td>
			<td><pre lang="json">
"1.19-alpine"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.annotations</td>
			<td>object</td>
			<td>Annotations for the gateway ingress</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.enabled</td>
			<td>bool</td>
			<td>Specifies whether an ingress for the gateway should be created</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.hosts</td>
			<td>list</td>
			<td>Hosts configuration for the gateway ingress</td>
			<td><pre lang="json">
[
  {
    "host": "gateway.loki.example.com",
    "paths": [
      {
        "path": "/"
      }
    ]
  }
]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.ingress.tls</td>
			<td>list</td>
			<td>TLS configuration for the gateway ingress</td>
			<td><pre lang="json">
[
  {
    "hosts": [
      "gateway.loki.example.com"
    ],
    "secretName": "loki-gateway-tls"
  }
]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.file</td>
			<td>string</td>
			<td>Config file contents for Nginx. Passed through the `tpl` function to allow templating</td>
			<td><pre lang="">
See values.yaml
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.httpSnippet</td>
			<td>string</td>
			<td>Allows appending custom configuration to the http block</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.logFormat</td>
			<td>string</td>
			<td>NGINX log format</td>
			<td><pre lang="json">
"main '$remote_addr - $remote_user [$time_local]  $status '\n        '\"$request\" $body_bytes_sent \"$http_referer\" '\n        '\"$http_user_agent\" \"$http_x_forwarded_for\"';"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nginxConfig.serverSnippet</td>
			<td>string</td>
			<td>Allows appending custom configuration to the server block</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.nodeSelector</td>
			<td>object</td>
			<td>Node selector for gateway pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.podAnnotations</td>
			<td>object</td>
			<td>Annotations for gateway pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.podSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for gateway containers</td>
			<td><pre lang="json">
{
  "fsGroup": 101,
  "runAsGroup": 101,
  "runAsNonRoot": true,
  "runAsUser": 101
}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for gateway pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.httpGet.path</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.httpGet.port</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"http"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.initialDelaySeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
15
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.readinessProbe.timeoutSeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.replicas</td>
			<td>int</td>
			<td>Number of replicas for the gateway</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the gateway</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.annotations</td>
			<td>object</td>
			<td>Annotations for the gateway service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.clusterIP</td>
			<td>string</td>
			<td>ClusterIP of the gateway service</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.labels</td>
			<td>object</td>
			<td>Labels for gateway service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.loadBalancerIP</td>
			<td>string</td>
			<td>Load balancer IPO address if service type is LoadBalancer</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.nodePort</td>
			<td>int</td>
			<td>Node port if service type is NodePort</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.port</td>
			<td>int</td>
			<td>Port of the gateway service</td>
			<td><pre lang="json">
80
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.service.type</td>
			<td>string</td>
			<td>Type of the gateway service</td>
			<td><pre lang="json">
"ClusterIP"
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the gateway to shutdown before it is killed</td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.tolerations</td>
			<td>list</td>
			<td>Tolerations for gateway pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>gateway.verboseLogging</td>
			<td>bool</td>
			<td>Enable logging of 2xx and 3xx HTTP requests</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>global.clusterDomain</td>
			<td>string</td>
			<td>configures cluster domain ("cluster.local" by default)</td>
			<td><pre lang="json">
"cluster.local"
</pre>
</td>
		</tr>
		<tr>
			<td>global.dnsNamespace</td>
			<td>string</td>
			<td>configures DNS service namespace</td>
			<td><pre lang="json">
"kube-system"
</pre>
</td>
		</tr>
		<tr>
			<td>global.dnsService</td>
			<td>string</td>
			<td>configures DNS service name</td>
			<td><pre lang="json">
"kube-dns"
</pre>
</td>
		</tr>
		<tr>
			<td>global.image.registry</td>
			<td>string</td>
			<td>Overrides the Docker registry globally for all images</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>global.priorityClassName</td>
			<td>string</td>
			<td>Overrides the priorityClassName for all pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>imagePullSecrets</td>
			<td>list</td>
			<td>Image pull secrets for Docker images</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.annotations</td>
			<td>object</td>
			<td></td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.hosts[0]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"loki.example.com"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[0]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/tail"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[1]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/tail"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[2]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[3]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[4]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[5]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/prometheus/api/v1/rules"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.read[6]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/prometheus/api/v1/alerts"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.write[0]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/api/prom/push"
</pre>
</td>
		</tr>
		<tr>
			<td>ingress.paths.write[1]</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/loki/api/v1/push"
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"bitnami/kubectl"
</pre>
</td>
		</tr>
		<tr>
			<td>kubectlImage.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>loki.analytics</td>
			<td>object</td>
			<td>Optional analytics configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.auth_enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>loki.commonConfig</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#common_config for more info on how to provide a common configuration</td>
			<td><pre lang="json">
{
  "path_prefix": "/var/loki",
  "replication_factor": 3
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.compactor</td>
			<td>object</td>
			<td>Optional compactor configuration</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.config</td>
			<td>string</td>
			<td>Config file contents for Loki</td>
			<td><pre lang="">
See values.yaml
</pre>
</td>
		</tr>
		<tr>
			<td>loki.containerSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for Loki containers</td>
			<td><pre lang="json">
{
  "allowPrivilegeEscalation": false,
  "capabilities": {
    "drop": [
      "ALL"
    ]
  },
  "readOnlyRootFilesystem": true
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.existingSecretForConfig</td>
			<td>string</td>
			<td>Specify an existing secret containing loki configuration. If non-empty, overrides `loki.config`</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/loki"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>loki.limits_config</td>
			<td>object</td>
			<td>Limits config</td>
			<td><pre lang="json">
{
  "enforce_metric_name": false,
  "max_cache_freshness_per_query": "10m",
  "reject_old_samples": true,
  "reject_old_samples_max_age": "168h",
  "split_queries_by_interval": "15m"
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.memcached</td>
			<td>object</td>
			<td>Configure memcached as an external cache for chunk and results cache. Disabled by default must enable and specify a host for each cache you would like to use.</td>
			<td><pre lang="json">
{
  "chunk_cache": {
    "batch_size": 256,
    "enabled": false,
    "host": "",
    "parallelism": 10,
    "service": "memcached-client"
  },
  "results_cache": {
    "default_validity": "12h",
    "enabled": false,
    "host": "",
    "service": "memcached-client",
    "timeout": "500ms"
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.podAnnotations</td>
			<td>object</td>
			<td>Common annotations for all pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.podSecurityContext</td>
			<td>object</td>
			<td>The SecurityContext for Loki pods</td>
			<td><pre lang="json">
{
  "fsGroup": 10001,
  "runAsGroup": 10001,
  "runAsNonRoot": true,
  "runAsUser": 10001
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.query_scheduler</td>
			<td>object</td>
			<td>Additional query scheduler config</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.httpGet.path</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"/ready"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.httpGet.port</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
"http-metrics"
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.initialDelaySeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>loki.readinessProbe.timeoutSeconds</td>
			<td>int</td>
			<td></td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>loki.revisionHistoryLimit</td>
			<td>int</td>
			<td>The number of old ReplicaSets to retain to allow rollback</td>
			<td><pre lang="json">
10
</pre>
</td>
		</tr>
		<tr>
			<td>loki.rulerConfig</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#ruler for more info on configuring ruler</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.schemaConfig</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#schema_config for more info on how to configure schemas</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.server</td>
			<td>object</td>
			<td>Check https://grafana.com/docs/loki/latest/configuration/#server for more info on the server configuration.</td>
			<td><pre lang="json">
{
  "grpc_listen_port": 9095,
  "http_listen_port": 3100
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.storage</td>
			<td>object</td>
			<td>Storage config. Providing this will automatically populate all necessary storage configs in the templated config.</td>
			<td><pre lang="json">
{
  "bucketNames": {
    "admin": "admin",
    "chunks": "chunks",
    "ruler": "ruler"
  },
  "filesystem": {
    "chunks_directory": "/var/loki/chunks",
    "rules_directory": "/var/loki/rules"
  },
  "gcs": {
    "chunkBufferSize": 0,
    "enableHttp2": true,
    "requestTimeout": "0s"
  },
  "s3": {
    "accessKeyId": null,
    "endpoint": null,
    "http_config": {},
    "insecure": false,
    "region": null,
    "s3": null,
    "s3ForcePathStyle": false,
    "secretAccessKey": null
  },
  "type": "s3"
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.storage_config</td>
			<td>object</td>
			<td>Additional storage config</td>
			<td><pre lang="json">
{
  "hedging": {
    "at": "250ms",
    "max_per_second": 20,
    "up_to": 3
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>loki.structuredConfig</td>
			<td>object</td>
			<td>Structured loki configuration, takes precedence over `loki.config`, `loki.schemaConfig`, `loki.storageConfig`</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>migrate</td>
			<td>object</td>
			<td>Options that may be necessary when performing a migration from another helm chart</td>
			<td><pre lang="json">
{
  "fromDistributed": {
    "enabled": false,
    "memberlistService": ""
  }
}
</pre>
</td>
		</tr>
		<tr>
			<td>migrate.fromDistributed</td>
			<td>object</td>
			<td>When migrating from a distributed chart like loki-distributed or enterprise-logs</td>
			<td><pre lang="json">
{
  "enabled": false,
  "memberlistService": ""
}
</pre>
</td>
		</tr>
		<tr>
			<td>migrate.fromDistributed.enabled</td>
			<td>bool</td>
			<td>Set to true if migrating from a distributed helm chart</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>migrate.fromDistributed.memberlistService</td>
			<td>string</td>
			<td>If migrating from a distributed service, provide the distributed deployment's memberlist service DNS so the new deployment can join it's ring.</td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>minio</td>
			<td>object</td>
			<td>-----------------------------------</td>
			<td><pre lang="json">
{
  "buckets": [
    {
      "name": "chunks",
      "policy": "none",
      "purge": false
    },
    {
      "name": "ruler",
      "policy": "none",
      "purge": false
    },
    {
      "name": "admin",
      "policy": "none",
      "purge": false
    }
  ],
  "drivesPerNode": 2,
  "enabled": false,
  "persistence": {
    "size": "5Gi"
  },
  "replicas": 1,
  "resources": {
    "requests": {
      "cpu": "100m",
      "memory": "128Mi"
    }
  },
  "rootPassword": "supersecret",
  "rootUser": "enterprise-logs"
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.alerts.annotations</td>
			<td>object</td>
			<td>Additional annotations for the alerts PrometheusRule resource</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.alerts.enabled</td>
			<td>bool</td>
			<td>If enabled, create PrometheusRule resource with Loki alerting rules</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.alerts.labels</td>
			<td>object</td>
			<td>Additional labels for the alerts PrometheusRule resource</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.alerts.namespace</td>
			<td>string</td>
			<td>Alternative namespace to create alerting rules PrometheusRule resource in</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.annotations</td>
			<td>object</td>
			<td>Additional annotations for the dashboards ConfigMap</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.enabled</td>
			<td>bool</td>
			<td>If enabled, create configmap with dashboards for monitoring Loki</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.labels</td>
			<td>object</td>
			<td>Additional labels for the dashboards ConfigMap</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.dashboards.namespace</td>
			<td>string</td>
			<td>Alternative namespace to create dashboards ConfigMap in</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.additionalGroups</td>
			<td>list</td>
			<td>Additional groups to add to the rules file</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.alerting</td>
			<td>bool</td>
			<td>Include alerting rules</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.annotations</td>
			<td>object</td>
			<td>Additional annotations for the rules PrometheusRule resource</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.enabled</td>
			<td>bool</td>
			<td>If enabled, create PrometheusRule resource with Loki recording rules</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.labels</td>
			<td>object</td>
			<td>Additional labels for the rules PrometheusRule resource</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.rules.namespace</td>
			<td>string</td>
			<td>Alternative namespace to create recording rules PrometheusRule resource in</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.annotations</td>
			<td>object</td>
			<td>Grafana Agent annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.enableConfigReadAPI</td>
			<td>bool</td>
			<td>Enable the config read api on port 8080 of the agent</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.installOperator</td>
			<td>bool</td>
			<td>Controls whether to install the Grafana Agent Operator and its CRDs. Note that helm will not install CRDs if this flag is enabled during an upgrade. In that case install the CRDs manually from https://github.com/grafana/agent/tree/main/production/operator/crds</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.labels</td>
			<td>object</td>
			<td>Additional Grafana Agent labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.grafanaAgent.namespace</td>
			<td>string</td>
			<td>Alternative namespace for Grafana Agent resources</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.logsInstance.annotations</td>
			<td>object</td>
			<td>LogsInstance annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.logsInstance.clients</td>
			<td>string</td>
			<td>Additional clients for remote write</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.logsInstance.labels</td>
			<td>object</td>
			<td>Additional LogsInstance labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.logsInstance.namespace</td>
			<td>string</td>
			<td>Alternative namespace for LogsInstance resources</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.annotations</td>
			<td>object</td>
			<td>Additional annotations for the `loki-canary` Daemonset</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.enabled</td>
			<td>bool</td>
			<td></td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.extraArgs</td>
			<td>list</td>
			<td>Additional CLI arguments for the `loki-canary' command</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the canary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the canary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.image</td>
			<td>object</td>
			<td>Image to use for loki canary</td>
			<td><pre lang="json">
{
  "pullPolicy": "IfNotPresent",
  "registry": "docker.io",
  "repository": "grafana/loki-canary",
  "tag": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/loki-canary"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.nodeSelector</td>
			<td>object</td>
			<td>Node selector for canary pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the canary</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.lokiCanary.tolerations</td>
			<td>list</td>
			<td>Tolerations for canary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.podLogs.annotations</td>
			<td>object</td>
			<td>PodLogs annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.podLogs.labels</td>
			<td>object</td>
			<td>Additional PodLogs labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.podLogs.namespace</td>
			<td>string</td>
			<td>Alternative namespace for PodLogs resources</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.podLogs.relabelings</td>
			<td>list</td>
			<td>PodLogs relabel configs to apply to samples before scraping https://github.com/prometheus-operator/prometheus-operator/blob/master/Documentation/api.md#relabelconfig</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.selfMonitoring.tenant</td>
			<td>string</td>
			<td>Tenant to use for self monitoring</td>
			<td><pre lang="json">
"self-monitoring"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.annotations</td>
			<td>object</td>
			<td>ServiceMonitor annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.enabled</td>
			<td>bool</td>
			<td>If enabled, ServiceMonitor resources for Prometheus Operator are created</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.interval</td>
			<td>string</td>
			<td>ServiceMonitor scrape interval</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.labels</td>
			<td>object</td>
			<td>Additional ServiceMonitor labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance</td>
			<td>object</td>
			<td>If defined, will create a MetricsInstance for the Grafana Agent Operator.</td>
			<td><pre lang="json">
{
  "annotations": {},
  "labels": {},
  "remoteWrite": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance.annotations</td>
			<td>object</td>
			<td>MerticsInstance annotations</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance.labels</td>
			<td>object</td>
			<td>Additional MatricsInstance labels</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.metricsInstance.remoteWrite</td>
			<td>string</td>
			<td>If defined a MetricsInstance will be created to remote write metrics.</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.namespace</td>
			<td>string</td>
			<td>Alternative namespace for ServiceMonitor resources</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.namespaceSelector</td>
			<td>object</td>
			<td>Namespace selector for ServiceMonitor resources</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.relabelings</td>
			<td>list</td>
			<td>ServiceMonitor relabel configs to apply to samples before scraping https://github.com/prometheus-operator/prometheus-operator/blob/master/Documentation/api.md#relabelconfig</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.scheme</td>
			<td>string</td>
			<td>ServiceMonitor will use http by default, but you can pick https as well</td>
			<td><pre lang="json">
"http"
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.scrapeTimeout</td>
			<td>string</td>
			<td>ServiceMonitor scrape timeout in Go duration format (e.g. 15s)</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>monitoring.serviceMonitor.tlsConfig</td>
			<td>string</td>
			<td>ServiceMonitor will use these tlsConfig settings to make the health check requests</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>nameOverride</td>
			<td>string</td>
			<td>Overrides the chart's name</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.alertmanager.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespace the alertmanager is running in</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.alertmanager.podSelector</td>
			<td>object</td>
			<td>Specifies the alertmanager Pods. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.alertmanager.port</td>
			<td>int</td>
			<td>Specify the alertmanager port used for alerting</td>
			<td><pre lang="json">
9093
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.discovery.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespace the discovery Pods are running in</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.discovery.podSelector</td>
			<td>object</td>
			<td>Specifies the Pods labels used for discovery. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.discovery.port</td>
			<td>int</td>
			<td>Specify the port used for discovery</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.enabled</td>
			<td>bool</td>
			<td>Specifies whether Network Policies should be created</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.externalStorage.cidrs</td>
			<td>list</td>
			<td>Specifies specific network CIDRs you want to limit access to</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.externalStorage.ports</td>
			<td>list</td>
			<td>Specify the port used for external storage, e.g. AWS S3</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.ingress.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespaces which are allowed to access the http port</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.ingress.podSelector</td>
			<td>object</td>
			<td>Specifies the Pods which are allowed to access the http port. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.metrics.cidrs</td>
			<td>list</td>
			<td>Specifies specific network CIDRs which are allowed to access the metrics port. In case you use namespaceSelector, you also have to specify your kubelet networks here. The metrics ports are also used for probes.</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.metrics.namespaceSelector</td>
			<td>object</td>
			<td>Specifies the namespaces which are allowed to access the metrics port</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>networkPolicy.metrics.podSelector</td>
			<td>object</td>
			<td>Specifies the Pods which are allowed to access the metrics port. As this is cross-namespace communication, you also need the namespaceSelector.</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>rbac.pspEnabled</td>
			<td>bool</td>
			<td>If pspEnabled true, a PodSecurityPolicy is created for K8s that use psp.</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>rbac.sccEnabled</td>
			<td>bool</td>
			<td>For OpenShift set pspEnabled to 'false' and sccEnabled to 'true' to use the SecurityContextConstraints.</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>read.affinity</td>
			<td>string</td>
			<td>Affinity for read pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling for the read, this is only used if `queryIndex.enabled: true`</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the read</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the read</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilisation percentage for the read</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>read.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilisation percentage for the read</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the read</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>read.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the read image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the read image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the read image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.nodeSelector</td>
			<td>object</td>
			<td>Node selector for read pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.persistence.size</td>
			<td>string</td>
			<td>Size of persistent disk</td>
			<td><pre lang="json">
"10Gi"
</pre>
</td>
		</tr>
		<tr>
			<td>read.persistence.storageClass</td>
			<td>string</td>
			<td>Storage class to be used. If defined, storageClassName: <storageClass>. If set to "-", storageClassName: "", which disables dynamic provisioning. If empty or set to null, no storageClassName spec is set, choosing the default provisioner (gp2 on AWS, standard on GKE, AWS, and OpenStack).</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.podAnnotations</td>
			<td>object</td>
			<td>Annotations for read pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for read pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>read.replicas</td>
			<td>int</td>
			<td>Number of replicas for the read</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>read.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the read</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.selectorLabels</td>
			<td>object</td>
			<td>Additional selecto labels for each `read` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.serviceLabels</td>
			<td>object</td>
			<td>Labels for read service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>read.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the read to shutdown before it is killed</td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>read.tolerations</td>
			<td>list</td>
			<td>Tolerations for read pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.annotations</td>
			<td>object</td>
			<td>Annotations for the service account</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.automountServiceAccountToken</td>
			<td>bool</td>
			<td>Set this toggle to false to opt out of automounting API credentials for the service account</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.create</td>
			<td>bool</td>
			<td>Specifies whether a ServiceAccount should be created</td>
			<td><pre lang="json">
true
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.imagePullSecrets</td>
			<td>list</td>
			<td>Image pull secrets for the service account</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>serviceAccount.name</td>
			<td>string</td>
			<td>The name of the ServiceAccount to use. If not set and create is true, a name is generated using the fullname template</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.affinity</td>
			<td>string</td>
			<td>Affinity for single binary pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.enabled</td>
			<td>bool</td>
			<td>Enable autoscaling, this is only used if `queryIndex.enabled: true`</td>
			<td><pre lang="json">
false
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.maxReplicas</td>
			<td>int</td>
			<td>Maximum autoscaling replicas for the single binary</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.minReplicas</td>
			<td>int</td>
			<td>Minimum autoscaling replicas for the single binary</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.targetCPUUtilizationPercentage</td>
			<td>int</td>
			<td>Target CPU utilisation percentage for the single binary</td>
			<td><pre lang="json">
60
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.autoscaling.targetMemoryUtilizationPercentage</td>
			<td>string</td>
			<td>Target memory utilisation percentage for the single binary</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraArgs</td>
			<td>list</td>
			<td>Labels for single binary service</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the single binary image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the single binary image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the single binary image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.nodeSelector</td>
			<td>object</td>
			<td>Node selector for single binary pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.persistence.size</td>
			<td>string</td>
			<td>Size of persistent disk</td>
			<td><pre lang="json">
"10Gi"
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.persistence.storageClass</td>
			<td>string</td>
			<td>Storage class to be used. If defined, storageClassName: <storageClass>. If set to "-", storageClassName: "", which disables dynamic provisioning. If empty or set to null, no storageClassName spec is set, choosing the default provisioner (gp2 on AWS, standard on GKE, AWS, and OpenStack).</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.podAnnotations</td>
			<td>object</td>
			<td>Annotations for single binary pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for single binary pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.replicas</td>
			<td>int</td>
			<td>Number of replicas for the single binary</td>
			<td><pre lang="json">
1
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the single binary</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.selectorLabels</td>
			<td>object</td>
			<td>Additional selecto labels for each `single binary` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the single binary to shutdown before it is killed</td>
			<td><pre lang="json">
30
</pre>
</td>
		</tr>
		<tr>
			<td>singleBinary.tolerations</td>
			<td>list</td>
			<td>Tolerations for single binary pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>test</td>
			<td>object</td>
			<td>Section for configuring optional Helm test</td>
			<td><pre lang="json">
{
  "annotations": {},
  "enabled": true,
  "image": {
    "pullPolicy": "IfNotPresent",
    "registry": "docker.io",
    "repository": "grafana/loki-helm-test",
    "tag": null
  },
  "labels": {},
  "prometheusAddress": "http://prometheus:9090",
  "timeout": "1m"
}
</pre>
</td>
		</tr>
		<tr>
			<td>test.annotations</td>
			<td>object</td>
			<td>Additional annotations for test pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>test.image</td>
			<td>object</td>
			<td>Image to use for loki canary</td>
			<td><pre lang="json">
{
  "pullPolicy": "IfNotPresent",
  "registry": "docker.io",
  "repository": "grafana/loki-helm-test",
  "tag": null
}
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.pullPolicy</td>
			<td>string</td>
			<td>Docker image pull policy</td>
			<td><pre lang="json">
"IfNotPresent"
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.registry</td>
			<td>string</td>
			<td>The Docker registry</td>
			<td><pre lang="json">
"docker.io"
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.repository</td>
			<td>string</td>
			<td>Docker image repository</td>
			<td><pre lang="json">
"grafana/loki-helm-test"
</pre>
</td>
		</tr>
		<tr>
			<td>test.image.tag</td>
			<td>string</td>
			<td>Overrides the image tag whose default is the chart's appVersion</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>test.labels</td>
			<td>object</td>
			<td>Additional labels for the test pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>test.prometheusAddress</td>
			<td>string</td>
			<td>Address of the prometheus server to query for the test</td>
			<td><pre lang="json">
"http://prometheus:9090"
</pre>
</td>
		</tr>
		<tr>
			<td>test.timeout</td>
			<td>string</td>
			<td>Number of times to retry the test before failing</td>
			<td><pre lang="json">
"1m"
</pre>
</td>
		</tr>
		<tr>
			<td>tracing.jaegerAgentHost</td>
			<td>string</td>
			<td></td>
			<td><pre lang="json">
""
</pre>
</td>
		</tr>
		<tr>
			<td>write.affinity</td>
			<td>string</td>
			<td>Affinity for write pods. Passed through `tpl` and, thus, to be configured as string</td>
			<td><pre lang="">
Hard node and soft zone anti-affinity
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraArgs</td>
			<td>list</td>
			<td>Additional CLI args for the write</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraEnv</td>
			<td>list</td>
			<td>Environment variables to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraEnvFrom</td>
			<td>list</td>
			<td>Environment variables from secrets or configmaps to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraVolumeMounts</td>
			<td>list</td>
			<td>Volume mounts to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.extraVolumes</td>
			<td>list</td>
			<td>Volumes to add to the write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
		<tr>
			<td>write.image.registry</td>
			<td>string</td>
			<td>The Docker registry for the write image. Overrides `loki.image.registry`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.image.repository</td>
			<td>string</td>
			<td>Docker image repository for the write image. Overrides `loki.image.repository`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.image.tag</td>
			<td>string</td>
			<td>Docker image tag for the write image. Overrides `loki.image.tag`</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.nodeSelector</td>
			<td>object</td>
			<td>Node selector for write pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.persistence.size</td>
			<td>string</td>
			<td>Size of persistent disk</td>
			<td><pre lang="json">
"10Gi"
</pre>
</td>
		</tr>
		<tr>
			<td>write.persistence.storageClass</td>
			<td>string</td>
			<td>Storage class to be used. If defined, storageClassName: <storageClass>. If set to "-", storageClassName: "", which disables dynamic provisioning. If empty or set to null, no storageClassName spec is set, choosing the default provisioner (gp2 on AWS, standard on GKE, AWS, and OpenStack).</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.podAnnotations</td>
			<td>object</td>
			<td>Annotations for write pods</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.priorityClassName</td>
			<td>string</td>
			<td>The name of the PriorityClass for write pods</td>
			<td><pre lang="json">
null
</pre>
</td>
		</tr>
		<tr>
			<td>write.replicas</td>
			<td>int</td>
			<td>Number of replicas for the write</td>
			<td><pre lang="json">
3
</pre>
</td>
		</tr>
		<tr>
			<td>write.resources</td>
			<td>object</td>
			<td>Resource requests and limits for the write</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.selectorLabels</td>
			<td>object</td>
			<td>Additional selector labels for each `write` pod</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.serviceLabels</td>
			<td>object</td>
			<td>Labels for ingestor service</td>
			<td><pre lang="json">
{}
</pre>
</td>
		</tr>
		<tr>
			<td>write.terminationGracePeriodSeconds</td>
			<td>int</td>
			<td>Grace period to allow the write to shutdown before it is killed. Especially for the ingestor, this must be increased. It must be long enough so writes can be gracefully shutdown flushing/transferring all data and to successfully leave the member ring on shutdown.</td>
			<td><pre lang="json">
300
</pre>
</td>
		</tr>
		<tr>
			<td>write.tolerations</td>
			<td>list</td>
			<td>Tolerations for write pods</td>
			<td><pre lang="json">
[]
</pre>
</td>
		</tr>
	</tbody>
</table>
{{< /responsive-table >}}

